import { Switch, Route } from "wouter";
import { QueryClientProvider } from "@tanstack/react-query";
import { queryClient } from "./lib/queryClient";
import { Toaster } from "./components/ui/toaster";
import { PrivacyProvider } from "./components/privacy-provider";
import { CookieBanner } from "./components/ui/cookie-banner";
import { PrivacyPopup } from "./components/ui/privacy-popup";
import { CoreWebVitals } from "./components/core-web-vitals";
import { PerformanceOptimizer } from "./components/performance-optimizer";
import { CSSOptimizer } from "./components/css-optimizer";
import { EnhancedStructuredData } from "./components/enhanced-structured-data";
import { SecurityHeaders } from "./components/security-headers";
import { ScrollToTop } from "./components/scroll-to-top";
import Header from "./components/layout/header";
import Footer from "./components/layout/footer";
import { useState, useEffect } from "react";
import { lazy, Suspense } from "react";
import { suppressResizeObserverWarnings, patchResizeObserver, disableResizeObserverErrors } from "./utils/resize-observer-fix";

// Lazy load all pages for better code splitting
const Home = lazy(() => import("./pages/home"));
const About = lazy(() => import("./pages/about"));
const Contact = lazy(() => import("./pages/contact"));
const Startups = lazy(() => import("./pages/startups"));
const NotFound = lazy(() => import("./pages/not-found"));
const VentureBuilding = lazy(() => import("./pages/services/venture-building"));
const MarketIntelligence = lazy(() => import("./pages/services/market-intelligence"));
const StrategicConsulting = lazy(() => import("./pages/services/strategic-consulting"));
const PrivacyPolicy = lazy(() => import("./pages/privacy-policy"));
const TermsOfService = lazy(() => import("./pages/terms-of-service"));
const CookiePolicy = lazy(() => import("./pages/cookie-policy"));

// Loading component
const PageLoader = () => (
  <div className="min-h-screen flex items-center justify-center">
    <div className="animate-spin rounded-full h-8 w-8 border-b-2 border-primary"></div>
  </div>
);

function Router() {
  return (
    <Suspense fallback={<PageLoader />}>
      <Switch>
        <Route path="/" component={Home} />
        <Route path="/about" component={About} />
        <Route path="/startups" component={Startups} />
        <Route path="/contact" component={Contact} />
        <Route path="/services/venture-building" component={VentureBuilding} />
        <Route path="/services/market-intelligence" component={MarketIntelligence} />
        <Route path="/services/strategic-consulting" component={StrategicConsulting} />
        <Route path="/privacy-policy" component={PrivacyPolicy} />
        <Route path="/terms-of-service" component={TermsOfService} />
        <Route path="/cookie-policy" component={CookiePolicy} />
        <Route component={NotFound} />
      </Switch>
    </Suspense>
  );
}

function App() {
  const [isPrivacyPopupOpen, setIsPrivacyPopupOpen] = useState(false);

  // Initialize ResizeObserver fix on app start
  useEffect(() => {
    // Use the most aggressive approach to completely eliminate ResizeObserver errors
    disableResizeObserverErrors();
    suppressResizeObserverWarnings();
    patchResizeObserver();
  }, []);



  const handleAcceptAll = () => {
    const allAccepted = {
      essential: true,
      analytics: true,
      marketing: true,
      functional: true,
    };
    localStorage.setItem('cookie-preferences', JSON.stringify(allAccepted));
    // Initialize analytics if accepted
    if (allAccepted.analytics) {
      console.log('Analytics cookies accepted');
    }
  };

  const handleRejectAll = () => {
    const onlyEssential = {
      essential: true,
      analytics: false,
      marketing: false,
      functional: false,
    };
    localStorage.setItem('cookie-preferences', JSON.stringify(onlyEssential));
    console.log('Only essential cookies accepted');
  };

  const handleCustomize = () => {
    setIsPrivacyPopupOpen(true);
  };

  const handleSavePreferences = (preferences: any) => {
    // Handle saving preferences and initializing services based on consent
    if (preferences.analytics) {
      console.log('Analytics cookies accepted');
    }
    if (preferences.marketing) {
      console.log('Marketing cookies accepted');
    }
    if (preferences.functional) {
      console.log('Functional cookies accepted');
    }
  };


  return (
    <QueryClientProvider client={queryClient}>
      <PrivacyProvider>
        <ScrollToTop />
        <div className="flex flex-col min-h-screen">
          <PerformanceOptimizer />
          <CoreWebVitals />
          <CSSOptimizer />
          <SecurityHeaders />
          <EnhancedStructuredData page="home" />
          <Header />
          <div className="flex-grow">
            <Router />
          </div>
          <Footer />
        </div>
        <Toaster />

        {/* Privacy Settings Popup */}
        <PrivacyPopup
          isOpen={isPrivacyPopupOpen}
          onClose={() => setIsPrivacyPopupOpen(false)}
          onSave={handleSavePreferences}
        />
      </PrivacyProvider>

      {/* Cookie Banner - Moved outside to prevent positioning issues */}
      <CookieBanner
        onAcceptAll={handleAcceptAll}
        onRejectAll={handleRejectAll}
        onCustomize={handleCustomize}
      />
    </QueryClientProvider>
  );
}

export default App;